@@ -105,15 +105,15 @@ class KayobeAnsibleMixin(object):
         tags = None if install else "config"
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags=tags,
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
         if service_config:
             playbooks = _build_playbook_list("kolla-openstack")
             self.run_kayobe_playbooks(parsed_args, playbooks,
-                                      ignore_limit=True, check=False)
+                                      ignore_limit=True)
         if bifrost_config:
             playbooks = _build_playbook_list("kolla-bifrost")
             self.run_kayobe_playbooks(parsed_args, playbooks,
-                                      ignore_limit=True, check=False)
+                                      ignore_limit=True)
 
 
 class KollaAnsibleMixin(object):
@@ -261,7 +261,7 @@ class ControlHostBootstrap(KayobeAnsibleMixin, KollaAnsibleMixin, VaultMixin,
             ka_tags = "install"
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags=ka_tags,
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
 
         if passwords_exist:
             # If we are bootstrapping a control host for an existing
@@ -301,7 +301,7 @@ class ControlHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
         self.run_kayobe_playbooks(parsed_args, playbooks, ignore_limit=True)
         playbooks = _build_playbook_list("kolla-ansible")
         self.run_kayobe_playbooks(parsed_args, playbooks, tags="install",
-                                  ignore_limit=True, check=False)
+                                  ignore_limit=True)
 
 
 class ConfigurationDump(KayobeAnsibleMixin, VaultMixin, Command):
@@ -424,8 +424,7 @@ class PhysicalNetworkConfigure(KayobeAnsibleMixin, VaultMixin, Command):
                                  extra_vars=extra_vars)
 
 
-class SeedHypervisorHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin,
-                                  VaultMixin, Command):
+class SeedHypervisorHostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
     """Configure the seed hypervisor node host OS and services.
 
     * Allocate IP addresses for all configured networks.
@@ -572,8 +571,7 @@ class SeedVMDeprovision(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
                                  _get_playbook_path("seed-vm-deprovision"))
 
 
-class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
-                        Command):
+class SeedHostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
     """Configure the seed node host OS and services.
 
     * Allocate IP addresses for all configured networks.
@@ -619,27 +617,12 @@ class SeedHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
 
         # Run kayobe playbooks.
-        kwargs = {}
+        extra_vars = {"kayobe_action": "deploy"}
         if parsed_args.wipe_disks:
-            kwargs["extra_vars"] = {"wipe_disks": True}
+            extra_vars["wipe_disks"] = True
         playbooks = _build_playbook_list("seed-host-configure")
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed",
-                                  **kwargs)
-
-        self.generate_kolla_ansible_config(parsed_args, service_config=False)
-
-        # Run kolla-ansible bootstrap-servers.
-        self.run_kolla_ansible_seed(parsed_args, "bootstrap-servers")
-
-        # Run final kayobe playbooks.
-        playbooks = _build_playbook_list("docker")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="seed")
-
-        # Optionally, deploy a Docker Registry.
-        playbooks = _build_playbook_list("docker-registry")
-        extra_vars = {"kayobe_action": "deploy"}
-        self.run_kayobe_playbooks(parsed_args, playbooks,
-                                  extra_vars=extra_vars, limit="seed")
+                                  extra_vars=extra_vars)
 
 
 class SeedHostPackageUpdate(KayobeAnsibleMixin, VaultMixin, Command):
@@ -689,8 +672,7 @@ class SeedHostCommandRun(KayobeAnsibleMixin, VaultMixin, Command):
                                   extra_vars=extra_vars)
 
 
-class SeedHostUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
-                      Command):
+class SeedHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
     """Upgrade the seed host services.
 
     Performs the changes necessary to make the host services suitable for the
@@ -879,8 +861,7 @@ class InfraVMDeprovision(KayobeAnsibleMixin, VaultMixin, Command):
                                  ignore_limit=True, extra_vars=extra_vars)
 
 
-class InfraVMHostConfigure(KayobeAnsibleMixin, VaultMixin,
-                           Command):
+class InfraVMHostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
     """Configure the infra VMs host OS and services.
 
     * Allocate IP addresses for all configured networks.
@@ -1106,8 +1087,7 @@ class OvercloudDeprovision(KayobeAnsibleMixin, VaultMixin, Command):
 
     def take_action(self, parsed_args):
         self.app.LOG.debug("Deprovisioning overcloud")
-        playbooks = _build_playbook_list("kolla-bifrost-hostvars",
-                                         "overcloud-deprovision")
+        playbooks = _build_playbook_list("overcloud-deprovision")
         self.run_kayobe_playbooks(parsed_args, playbooks)
 
 
@@ -1127,8 +1107,7 @@ class OvercloudFactsGather(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kolla_ansible_overcloud(parsed_args, "gather-facts")
 
 
-class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
-                             Command):
+class OvercloudHostConfigure(KayobeAnsibleMixin, VaultMixin, Command):
     """Configure the overcloud host OS and services.
 
     * Allocate IP addresses for all configured networks.
@@ -1180,16 +1159,6 @@ class OvercloudHostConfigure(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
         self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud",
                                   **kwargs)
 
-        self.generate_kolla_ansible_config(parsed_args, service_config=False)
-
-        # Kolla-ansible bootstrap-servers.
-        self.run_kolla_ansible_overcloud(parsed_args, "bootstrap-servers")
-
-        # Further kayobe playbooks.
-        playbooks = _build_playbook_list(
-            "docker", "swift-block-devices", "compute-libvirt-host")
-        self.run_kayobe_playbooks(parsed_args, playbooks, limit="overcloud")
-
 
 class OvercloudHostPackageUpdate(KayobeAnsibleMixin, VaultMixin, Command):
     """Update packages on the overcloud hosts."""
@@ -1238,8 +1207,7 @@ class OvercloudHostCommandRun(KayobeAnsibleMixin, VaultMixin, Command):
                                   extra_vars=extra_vars)
 
 
-class OvercloudHostUpgrade(KollaAnsibleMixin, KayobeAnsibleMixin, VaultMixin,
-                           Command):
+class OvercloudHostUpgrade(KayobeAnsibleMixin, VaultMixin, Command):
     """Upgrade the overcloud host services.
 
     Performs the changes necessary to make the host services suitable for the
@@ -1321,7 +1289,7 @@ class OvercloudServiceConfigurationGenerate(KayobeAnsibleMixin,
     def get_parser(self, prog_name):
         parser = super(OvercloudServiceConfigurationGenerate,
                        self).get_parser(prog_name)
-        group = parser.add_argument_group("Service Configuration")
+        group = parser.add_argument_group("Service Configuration Generate")
         group.add_argument("--node-config-dir", required=True,
                            help="the directory to store the config files on "
                                 "the remote node (required)")
@@ -1347,6 +1315,30 @@ class OvercloudServiceConfigurationGenerate(KayobeAnsibleMixin,
                                          extra_vars=extra_vars)
 
 
+class OvercloudServiceConfigurationValidate(KayobeAnsibleMixin,
+                                            KollaAnsibleMixin, VaultMixin,
+                                            Command):
+    """Runs oslo config validator on the OpenStack control plane services."""
+
+    def get_parser(self, prog_name):
+        parser = super(OvercloudServiceConfigurationValidate,
+                       self).get_parser(prog_name)
+        group = parser.add_argument_group("Service Configuration Validate")
+        group.add_argument("--output-dir", required=True,
+                           help="the directory to store the results of running"
+                                "the config validator (required)")
+        return parser
+
+    def take_action(self, parsed_args):
+        self.app.LOG.debug("Validating overcloud service configuration")
+        extra_vars = {}
+        if parsed_args.output_dir:
+            extra_vars[
+                "service_config_validate_output_dir"] = parsed_args.output_dir
+        self.run_kolla_ansible_overcloud(parsed_args, "validate-config",
+                                         extra_vars=extra_vars)
+
+
 class OvercloudServiceConfigurationSave(KayobeAnsibleMixin, VaultMixin,
                                         Command):
     """Gather and save the overcloud service configuration files.
@@ -1360,7 +1352,7 @@ class OvercloudServiceConfigurationSave(KayobeAnsibleMixin, VaultMixin,
     def get_parser(self, prog_name):
         parser = super(OvercloudServiceConfigurationSave, self).get_parser(
             prog_name)
-        group = parser.add_argument_group("Service configuration")
+        group = parser.add_argument_group("Service Configuration Save")
         group.add_argument("--exclude",
                            help="optional comma-separated list of patterns "
                                 "matching filenames to exclude")
