@@ -62,8 +62,7 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="install",
-                ignore_limit=True,
-                check=False,
+                ignore_limit=True
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -96,8 +95,7 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags=None,
-                ignore_limit=True,
-                check=False,
+                ignore_limit=True
             ),
             mock.call(
                 mock.ANY,
@@ -142,8 +140,7 @@ class TestCase(unittest.TestCase):
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="install",
-                ignore_limit=True,
-                check=False,
+                ignore_limit=True
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -485,9 +482,7 @@ class TestCase(unittest.TestCase):
 
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_seed")
-    def test_seed_host_configure(self, mock_kolla_run, mock_run):
+    def test_seed_host_configure(self, mock_run):
         command = commands.SeedHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
@@ -508,46 +503,14 @@ class TestCase(unittest.TestCase):
                         "ansible", "seed-host-configure.yml"),
                 ],
                 limit="seed",
-            ),
-            mock.call(
-                mock.ANY,
-                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
-                tags="config",
-                ignore_limit=True,
-                check=False,
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "docker.yml"),
-                ],
-                limit="seed",
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible",
-                                              "docker-registry.yml"),
-                ],
-                limit="seed",
-                extra_vars={'kayobe_action': 'deploy'},
+                extra_vars={"kayobe_action": "deploy"},
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
 
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-            ),
-        ]
-        self.assertListEqual(expected_calls, mock_kolla_run.call_args_list)
-
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_seed")
-    def test_seed_host_configure_wipe_disks(self, mock_kolla_run, mock_run):
+    def test_seed_host_configure_wipe_disks(self, mock_run):
         command = commands.SeedHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args(["--wipe-disks"])
@@ -568,44 +531,13 @@ class TestCase(unittest.TestCase):
                         "ansible", "seed-host-configure.yml"),
                 ],
                 limit="seed",
-                extra_vars={"wipe_disks": True},
-            ),
-            mock.call(
-                mock.ANY,
-                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
-                tags="config",
-                ignore_limit=True,
-                check=False,
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "docker.yml"),
-                ],
-                limit="seed",
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible",
-                                              "docker-registry.yml"),
-                ],
-                limit="seed",
-                extra_vars={'kayobe_action': 'deploy'},
+                extra_vars={"kayobe_action": "deploy", "wipe_disks": True},
             ),
         ]
         print(expected_calls)
         print(mock_run.call_args_list)
         self.assertListEqual(expected_calls, mock_run.call_args_list)
 
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-            ),
-        ]
-        self.assertListEqual(expected_calls, mock_kolla_run.call_args_list)
-
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_seed_host_command_run(self, mock_run):
@@ -879,13 +811,11 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-bifrost.yml")],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -931,13 +861,11 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
                 [utils.get_data_files_path("ansible", "kolla-bifrost.yml")],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1192,7 +1120,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1257,8 +1184,6 @@ class TestCase(unittest.TestCase):
             mock.call(
                 mock.ANY,
                 [
-                    utils.get_data_files_path(
-                        "ansible", "kolla-bifrost-hostvars.yml"),
                     utils.get_data_files_path(
                         "ansible", "overcloud-deprovision.yml"),
                 ],
@@ -1291,7 +1216,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1306,9 +1230,7 @@ class TestCase(unittest.TestCase):
 
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure(self, mock_kolla_run, mock_run):
+    def test_overcloud_host_configure(self, mock_run):
         command = commands.OvercloudHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args([])
@@ -1330,41 +1252,12 @@ class TestCase(unittest.TestCase):
                 ],
                 limit="overcloud",
             ),
-            mock.call(
-                mock.ANY,
-                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
-                tags="config",
-                ignore_limit=True,
-                check=False,
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "docker.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "swift-block-devices.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "compute-libvirt-host.yml"),
-                ],
-                limit="overcloud",
-            ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
 
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-            ),
-        ]
-        self.assertListEqual(expected_calls, mock_kolla_run.call_args_list)
-
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
-    @mock.patch.object(commands.KollaAnsibleMixin,
-                       "run_kolla_ansible_overcloud")
-    def test_overcloud_host_configure_wipe_disks(self, mock_kolla_run,
-                                                 mock_run):
+    def test_overcloud_host_configure_wipe_disks(self, mock_run):
         command = commands.OvercloudHostConfigure(TestApp(), [])
         parser = command.get_parser("test")
         parsed_args = parser.parse_args(["--wipe-disks"])
@@ -1387,35 +1280,9 @@ class TestCase(unittest.TestCase):
                 limit="overcloud",
                 extra_vars={"wipe_disks": True},
             ),
-            mock.call(
-                mock.ANY,
-                [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
-                tags="config",
-                ignore_limit=True,
-                check=False,
-            ),
-            mock.call(
-                mock.ANY,
-                [
-                    utils.get_data_files_path("ansible", "docker.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "swift-block-devices.yml"),
-                    utils.get_data_files_path(
-                        "ansible", "compute-libvirt-host.yml"),
-                ],
-                limit="overcloud",
-            ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
 
-        expected_calls = [
-            mock.call(
-                mock.ANY,
-                "bootstrap-servers",
-            ),
-        ]
-        self.assertListEqual(expected_calls, mock_kolla_run.call_args_list)
-
     @mock.patch.object(commands.KayobeAnsibleMixin,
                        "run_kayobe_playbooks")
     def test_overcloud_host_command_run(self, mock_run):
@@ -1559,7 +1426,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1591,7 +1457,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1622,7 +1487,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1631,7 +1495,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1663,7 +1526,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 tags="config",
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1672,7 +1534,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1726,7 +1587,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1735,7 +1595,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1793,7 +1652,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1802,7 +1660,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1848,7 +1705,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1857,7 +1713,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
         ]
         self.assertListEqual(expected_calls, mock_run.call_args_list)
@@ -1888,7 +1743,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1897,7 +1751,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1954,7 +1807,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags="config",
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -1963,7 +1815,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -2020,7 +1871,6 @@ class TestCase(unittest.TestCase):
                 [utils.get_data_files_path("ansible", "kolla-ansible.yml")],
                 ignore_limit=True,
                 tags=None,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
@@ -2029,7 +1879,6 @@ class TestCase(unittest.TestCase):
                                               "kolla-openstack.yml"),
                 ],
                 ignore_limit=True,
-                check=False,
             ),
             mock.call(
                 mock.ANY,
